==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_de_CH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_CH" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Letztes Video per mail versenden</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Ein oder mehrere Videos per mail senden</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video im Anhang</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Eine oder mehrere Dateien senden</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Ohne Rahmen</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rahmen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Gerät ist belegt</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Webcam auswählen</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauszeiger nicht aufnehmen</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>vokoscreen minimieren wenn Aufnahme startet</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Aufnahmezeit</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grösse in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Aktueller Bildschirmbereich</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>fps Einstellungen</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öffne Verzeichnis</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Letztes Video abspielen</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Video versenden</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuelle fps</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Gerät %1 ist belegt</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>Die aktuelle Framerate in den Einstellungen ist zu hoch</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Mailliste</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Entwickler</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta OpenSuse</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Aufnahme mit</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Im Systray anzeigen</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_de_CH.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de_CH" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Gerät ist belegt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Benutzt von</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Letztes Video per mail versenden</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Ein oder mehrere Videos per mail senden</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>abbrechen</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Video im Anhang</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Eine oder mehrere Dateien senden</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Rahmen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>auf Vollbild anzeigen</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Gerät ist belegt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Benutzt von</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>unbekannt</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Bereich</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lupe</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Mauszeiger nicht aufnehmen</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopfad</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>vokoscreen minimieren wenn Aufnahme startet</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Aufnahmezeit</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grösse in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Aktueller Bildschirmbereich</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>fps Einstellungen</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öffne Verzeichnis</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Letztes Video abspielen</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Video versenden</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Ein oder mehrere Geräte auswählen</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuelle fps</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Weiter</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Mailliste</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Entwickler</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta OpenSuse</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Aufnahme mit</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Quellcode</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Im Systray anzeigen</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Neue Version verfügbar</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Webcam auswählen</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Gespiegelt</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>alle Bildschirme</translation>
    </message>
</context>
</TS>
